# Date

a date (year, month and day) in an idealized calendar

URI: http://www.w3.org/2001/XMLSchema#date

* [base](https://w3id.org/linkml/base): XSDDate


* [repr](https://w3id.org/linkml/repr): str




## Identifier and Mapping Information


